<?php
/**
 * ETEAMS back compat functionality.
 *
 * Prevents ETEAMS from running on WordPress versions prior to 3.6,
 * since this theme is not meant to be backwards compatible and relies on
 * many new functions and markup changes introduced in 3.6.
 *
 * @package WordPress
 * @subpackage ETEAMS
 * @since ETEAMS 1.0
 */

/**
 * Prevent switching to ETEAMS on old versions of WordPress. Switches
 * to the default theme.
 *
 * @since ETEAMS 1.0
 *
 * @return void
 */
function eteams_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'eteams_upgrade_notice' );
}
add_action( 'after_switch_theme', 'eteams_switch_theme' );

/**
 * Prints an update nag after an unsuccessful attempt to switch to
 * ETEAMS on WordPress versions prior to 3.6.
 *
 * @since ETEAMS 1.0
 *
 * @return void
 */
function eteams_upgrade_notice() {
	$message = sprintf( __( 'ETEAMS requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'eteams' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 3.6.
 *
 * @since ETEAMS 1.0
 *
 * @return void
 */
function eteams_customize() {
	wp_die( sprintf( __( 'ETEAMS requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'eteams' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'eteams_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 3.4.
 *
 * @since ETEAMS 1.0
 *
 * @return void
 */
function eteams_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'ETEAMS requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'eteams' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'eteams_preview' );